# PyOpenGLng

The official PyOpenGLng Home Page is located at http://fabricesalvaire.github.io/PyOpenGLng

The latest documentation build from the git repository is available at readthedocs.org

Written by Fabrice Salvaire.

# Introduction

PyOpenGLng, proudly blessed as is, is an experimental OpenGL wrapper for Python which generates the requested OpenGL API from the OpenGL XML API Registry and use an automatic translator to map the C API to Python. The interface between C and Python is supported by ctypes and also by CFFI which paves the way to use the pypy interpreter.

By design this wrapper supports all the OpenGL version, but it focus towards the programmable pipeline and the most recent OpenGL API. On Linux desktop, Mesa 3D Graphics Library release 10 (November 2013) supports the OpenGL 3.3 API for Intel HD GPU.

The Python package provides three components:

- an Oriented Object API to the OpenGL XML registry,
- a ctypes and CFFI wrapper,
- an experimental high level API.

Warning

We should test all the API to claim a compliance with the OpenGL API. Since the OpenGL API becomes more and more large and complex over the release, such attempt would require a huge amount of work. Up to now only a part of the API was tested successfully.

## Bibliography

The followings list of links provides an overview on the topic:

- PyOpenGL - the de facto standard OpenGL Python binding
- Vispy - a high-performance interactive 2D/3D data visualization library

# Installation

## Dependencies

PyOpenGLng requires the following dependencies:

> - Python 2.7
> - Numpy
> - freetype-py
> - PyQt 4.9 for the high level API and the examples

## Installation from PyPi Repository

PyOpenGLng is made available on the PyPI repository at https://pypi.python.org/pypi/PyOpenGLng

Run this command to install the last release:

    pip install PyOpenGLng

## Installation from Source

The PyOpenGLng source code is hosted at https://github.com/FabriceSalvaire/PyOpenGLng

To clone the Git repository, run this command in a terminal:

    git clone git@github.com:FabriceSalvaire/PyOpenGLng.git

Then to build and install PyOpenGLng run these commands:

    python setup.py build
    python setup.py install